@@ -932,6 +932,16 @@ class TestBox:
 
             _parse_box_dots({}, "-")
 
+        with pytest.raises(KeyError):
+            b["a.b"]
+        with pytest.raises(BoxKeyError):
+            b["a.b"]
+
+        with pytest.raises(KeyError):
+            del b["a.b"]
+        with pytest.raises(BoxKeyError):
+            del b["a.b"]
+
     def test_unicode(self):
         bx = Box()
         bx["\U0001f631"] = 4
